@@ -324,7 +324,7 @@ class WndManageEmissionLines(SecondaryWindow):
 
                     item = QTableWidgetItem(s)
 
-                    item.setTextAlignment(Qt.AlignRight | Qt.AlignVCenter)
+                    item.setTextAlignment(int(Qt.AlignRight | Qt.AlignVCenter))
 
                     # Set all columns not editable (unless needed)
                     if label not in self.tbl_cols_editable:
