@@ -1,5 +1,4 @@
-from __future__ import (absolute_import, division,
-                        print_function)
+from __future__ import absolute_import, division, print_function
 
 import numpy as np
 import math
@@ -17,9 +16,10 @@ from ..core.xrf_utils import check_if_eline_supported
 from .draw_image import DrawImageAdvanced
 
 import logging
+
 logger = logging.getLogger(__name__)
 
-np.seterr(divide='ignore', invalid='ignore')  # turn off warning on invalid division
+np.seterr(divide="ignore", invalid="ignore")  # turn off warning on invalid division
 
 
 class DrawImageRGB(Atom):
@@ -67,6 +67,7 @@ class DrawImageRGB(Atom):
     plot_all : Bool
         to control plot all of the data or not
     """
+
     # Reference to FileIOMOdel
     io_model = Typed(object)
 
@@ -117,11 +118,21 @@ class DrawImageRGB(Atom):
 
         self.fig = plt.figure(figsize=(3, 2))
 
-        self.rgb_name_list = ['R', 'G', 'B']
+        self.rgb_name_list = ["R", "G", "B"]
 
         # Do not apply scaler norm on following data
-        self.name_not_scalable = ['r2_adjust', 'r_factor', 'alive', 'dead', 'elapsed_time',
-                                  'scaler_alive', 'i0_time', 'time', 'time_diff', 'dwell_time']
+        self.name_not_scalable = [
+            "r2_adjust",
+            "r_factor",
+            "alive",
+            "dead",
+            "elapsed_time",
+            "scaler_alive",
+            "i0_time",
+            "time",
+            "time_diff",
+            "dwell_time",
+        ]
 
         self.rgb_keys = ["red", "green", "blue"]
         self._init_rgb_dict()
@@ -136,7 +147,7 @@ class DrawImageRGB(Atom):
         changed : bool
             True - 'io_model.img_dict` was updated, False - ignore
         """
-        if change['value']:
+        if change["value"]:
             self.select_dataset(self.io_model.img_dict_default_selected_item)
             self.init_plot_status()
 
@@ -147,7 +158,7 @@ class DrawImageRGB(Atom):
         # init of scaler for normalization
         self.scaler_name_index = 0
 
-        scaler_groups = [v for v in list(self.io_model.img_dict.keys()) if 'scaler' in v]
+        scaler_groups = [v for v in list(self.io_model.img_dict.keys()) if "scaler" in v]
         if len(scaler_groups) > 0:
             # self.scaler_group_name = scaler_groups[0]
             self.scaler_norm_dict = self.io_model.img_dict[scaler_groups[0]]
@@ -157,8 +168,9 @@ class DrawImageRGB(Atom):
             self.scaler_items.sort()
             self.scaler_data = None
 
-        logger.debug('The following groups are included for RGB image display: {}'.
-                     format(self.io_model.img_dict_keys))
+        logger.debug(
+            "The following groups are included for RGB image display: {}".format(self.io_model.img_dict_keys)
+        )
 
         self.show_image()
 
@@ -179,7 +191,7 @@ class DrawImageRGB(Atom):
                 self.dict_to_plot = {}
                 self.map_keys.clear()
                 self.init_limits_and_stat()
-                self.img_title = ''
+                self.img_title = ""
 
             elif self.data_opt > 0:
                 plot_item = self._get_current_plot_item()
@@ -209,8 +221,9 @@ class DrawImageRGB(Atom):
         plot_item = self._get_current_plot_item()
         keys_unsorted = list(self.io_model.img_dict[plot_item].keys())
         if len(keys_unsorted) != len(set(keys_unsorted)):
-            logger.warning("DrawImageAdvanced:set_map_keys(): repeated keys "
-                           f"in the dictionary 'img_dict': {keys_unsorted}")
+            logger.warning(
+                f"DrawImageAdvanced:set_map_keys(): repeated keys in the dictionary 'img_dict': {keys_unsorted}"
+            )
         keys_elines, keys_scalers = [], []
         for key in keys_unsorted:
             if check_if_eline_supported(key):  # Check if 'key' is an emission line (such as "Ca_K")
@@ -235,16 +248,18 @@ class DrawImageRGB(Atom):
             self.scaler_data = None
         else:
             try:
-                scaler_name = self.scaler_items[self.scaler_name_index-1]
+                scaler_name = self.scaler_items[self.scaler_name_index - 1]
             except IndexError:
                 scaler_name = None
             if scaler_name:
                 self.scaler_data = self.scaler_norm_dict[scaler_name]
-                logger.info('Use scaler data to normalize, '
-                            'and the shape of scaler data is {}, '
-                            'with (low, high) as ({}, {})'.format(self.scaler_data.shape,
-                                                                  np.min(self.scaler_data),
-                                                                  np.max(self.scaler_data)))
+                logger.info(
+                    "Use scaler data to normalize, "
+                    "and the shape of scaler data is {}, "
+                    "with (low, high) as ({}, {})".format(
+                        self.scaler_data.shape, np.min(self.scaler_data), np.max(self.scaler_data)
+                    )
+                )
         self.set_low_high_value()  # reset low high values based on normalization
         self.show_image()
 
@@ -274,8 +289,7 @@ class DrawImageRGB(Atom):
         self.show_image()
 
     def set_low_high_value(self):
-        """Set default low and high values based on normalization for each image.
-        """
+        """Set default low and high values based on normalization for each image."""
         # do not apply scaler norm on not scalable data
         self.range_dict.clear()
 
@@ -288,29 +302,30 @@ class DrawImageRGB(Atom):
                     scaler_dict=self.scaler_norm_dict,
                     scaler_name_default=self.get_selected_scaler_name(),
                     data_name=data_name,
-                    name_not_scalable=self.name_not_scalable)
+                    name_not_scalable=self.name_not_scalable,
+                )
             else:
                 # Normalize by the selected scaler in a regular way
-                data_arr = normalize_data_by_scaler(data_in=self.dict_to_plot[data_name],
-                                                    scaler=self.scaler_data,
-                                                    data_name=data_name,
-                                                    name_not_scalable=self.name_not_scalable)
+                data_arr = normalize_data_by_scaler(
+                    data_in=self.dict_to_plot[data_name],
+                    scaler=self.scaler_data,
+                    data_name=data_name,
+                    name_not_scalable=self.name_not_scalable,
+                )
 
             lowv, highv = np.min(data_arr), np.max(data_arr)
             # Create some 'artificially' small range in case the array is constant
             if lowv == highv:
                 lowv -= 0.005
                 highv += 0.005
-            self.range_dict[data_name] = {'low': lowv, 'low_default': lowv,
-                                          'high': highv, 'high_default': highv}
+            self.range_dict[data_name] = {"low": lowv, "low_default": lowv, "high": highv, "high_default": highv}
 
     def reset_low_high(self, name):
-        """Reset low and high value to default based on normalization.
-        """
-        self.range_dict[name]['low'] = self.range_dict[name]['low_default']
-        self.range_dict[name]['high'] = self.range_dict[name]['high_default']
-        self.limit_dict[name]['low'] = 0.0
-        self.limit_dict[name]['high'] = 100.0
+        """Reset low and high value to default based on normalization."""
+        self.range_dict[name]["low"] = self.range_dict[name]["low_default"]
+        self.range_dict[name]["high"] = self.range_dict[name]["high_default"]
+        self.limit_dict[name]["low"] = 0.0
+        self.limit_dict[name]["high"] = 100.0
         self.show_image()
 
     def _init_rgb_dict(self):
@@ -327,7 +342,7 @@ class DrawImageRGB(Atom):
         self._init_rgb_dict()
 
         self.limit_dict.clear()
-        self.limit_dict = {k: {'low': 0.0, 'high': 100.0} for k in self.map_keys}
+        self.limit_dict = {k: {"low": 0.0, "high": 100.0} for k in self.map_keys}
 
         self.set_low_high_value()
 
@@ -347,27 +362,32 @@ class DrawImageRGB(Atom):
 
         if self.scaler_data is not None:
             if np.count_nonzero(self.scaler_data) == 0:
-                logger.warning('scaler is zero - scaling was not applied')
+                logger.warning("scaler is zero - scaling was not applied")
             elif len(self.scaler_data[self.scaler_data == 0]) > 0:
-                logger.warning('scaler data has zero values')
+                logger.warning("scaler data has zero values")
 
         for i, k in enumerate(selected_name):
             q_norm_applied = False
             if self.quantitative_normalization:
                 # Quantitative normalization
-                data_arr, q_norm_applied = \
-                    self.img_model_adv.param_quant_analysis.apply_quantitative_normalization(
-                        data_in=self.dict_to_plot[k],
-                        scaler_dict=self.scaler_norm_dict,
-                        scaler_name_default=self.get_selected_scaler_name(),
-                        data_name=k,
-                        name_not_scalable=self.name_not_scalable)
+                (
+                    data_arr,
+                    q_norm_applied,
+                ) = self.img_model_adv.param_quant_analysis.apply_quantitative_normalization(
+                    data_in=self.dict_to_plot[k],
+                    scaler_dict=self.scaler_norm_dict,
+                    scaler_name_default=self.get_selected_scaler_name(),
+                    data_name=k,
+                    name_not_scalable=self.name_not_scalable,
+                )
             else:
                 # Normalize by the selected scaler in a regular way
-                data_arr = normalize_data_by_scaler(data_in=self.dict_to_plot[k],
-                                                    scaler=self.scaler_data,
-                                                    data_name=k,
-                                                    name_not_scalable=self.name_not_scalable)
+                data_arr = normalize_data_by_scaler(
+                    data_in=self.dict_to_plot[k],
+                    scaler=self.scaler_data,
+                    data_name=k,
+                    name_not_scalable=self.name_not_scalable,
+                )
 
             selected_data.append(data_arr)
             quant_norm_applied.append(q_norm_applied)
@@ -389,7 +409,7 @@ class DrawImageRGB(Atom):
         # While the data from the completed part of experiment may still be used,
         # plotting vs. x-y or scatter plot may not be displayed.
         positions_data_available = False
-        if 'positions' in self.io_model.img_dict.keys():
+        if "positions" in self.io_model.img_dict.keys():
             positions_data_available = True
 
         # Create local copy of self.pixel_or_pos and self.grid_interpolate
@@ -488,11 +508,12 @@ class DrawImageRGB(Atom):
 
             # xd_min, xd_max, yd_min, yd_max = min(self.x_pos), max(self.x_pos),
             #     min(self.y_pos), max(self.y_pos)
-            x_pos_2D = self.io_model.img_dict['positions']['x_pos']
-            y_pos_2D = self.io_model.img_dict['positions']['y_pos']
+            x_pos_2D = self.io_model.img_dict["positions"]["x_pos"]
+            y_pos_2D = self.io_model.img_dict["positions"]["y_pos"]
             xd_min, xd_max, yd_min, yd_max = x_pos_2D.min(), x_pos_2D.max(), y_pos_2D.min(), y_pos_2D.max()
-            xd_axis_min, xd_axis_max, yd_axis_min, yd_axis_max = \
-                _compute_equal_axes_ranges(xd_min, xd_max, yd_min, yd_max)
+            xd_axis_min, xd_axis_max, yd_axis_min, yd_axis_max = _compute_equal_axes_ranges(
+                xd_min, xd_max, yd_min, yd_max
+            )
 
             xd_min, xd_max = _adjust_data_range_using_min_ratio(xd_min, xd_max, xd_axis_max - xd_axis_min)
             yd_min, yd_max = _adjust_data_range_using_min_ratio(yd_min, yd_max, yd_axis_max - yd_axis_min)
@@ -515,8 +536,9 @@ class DrawImageRGB(Atom):
                 if (xd <= math.floor(yd / 100)) and (yd >= 200):
                     xd_min, xd_max = -math.floor(yd / 200), math.ceil(yd / 200)
 
-                xd_axis_min, xd_axis_max, yd_axis_min, yd_axis_max = \
-                    _compute_equal_axes_ranges(xd_min, xd_max, yd_min, yd_max)
+                xd_axis_min, xd_axis_max, yd_axis_min, yd_axis_max = _compute_equal_axes_ranges(
+                    xd_min, xd_max, yd_min, yd_max
+                )
 
         name_r, data_r, limits_r = "", None, {"low": 0, "high": 100.0}
         name_g, data_g, limits_g = "", None, {"low": 0, "high": 100.0}
@@ -574,15 +596,15 @@ class DrawImageRGB(Atom):
 
         # Interpolate non-uniformly spaced data to uniform grid
         if grid_interpolate_local:
-            data_r, _, _ = grid_interpolate(data_r,
-                                            self.io_model.img_dict['positions']['x_pos'],
-                                            self.io_model.img_dict['positions']['y_pos'])
-            data_g, _, _ = grid_interpolate(data_g,
-                                            self.io_model.img_dict['positions']['x_pos'],
-                                            self.io_model.img_dict['positions']['y_pos'])
-            data_b, _, _ = grid_interpolate(data_b,
-                                            self.io_model.img_dict['positions']['x_pos'],
-                                            self.io_model.img_dict['positions']['y_pos'])
+            data_r, _, _ = grid_interpolate(
+                data_r, self.io_model.img_dict["positions"]["x_pos"], self.io_model.img_dict["positions"]["y_pos"]
+            )
+            data_g, _, _ = grid_interpolate(
+                data_g, self.io_model.img_dict["positions"]["x_pos"], self.io_model.img_dict["positions"]["y_pos"]
+            )
+            data_b, _, _ = grid_interpolate(
+                data_b, self.io_model.img_dict["positions"]["x_pos"], self.io_model.img_dict["positions"]["y_pos"]
+            )
 
         # The dictionaries 'rgb_view_data' and 'pos_limits' are used for monitoring
         #   the map values at current cursor positions.
@@ -593,34 +615,31 @@ class DrawImageRGB(Atom):
             rgb_view_data["green"] = data_g
         if data_b is not None:
             rgb_view_data["blue"] = data_b
-        pos_limits = {"x_low": xd_min, "x_high": xd_max,
-                      "y_low": yd_min, "y_high": yd_max}
+        pos_limits = {"x_low": xd_min, "x_high": xd_max, "y_low": yd_min, "y_high": yd_max}
 
         # Normalize data
         data_r_norm = _norm_data(data_r)
         data_g_norm = _norm_data(data_g)
         data_b_norm = _norm_data(data_b)
 
-        data_r_norm = _stretch_range(data_r_norm, limits_r['low'], limits_r['high'])
-        data_g_norm = _stretch_range(data_g_norm, limits_g['low'], limits_g['high'])
-        data_b_norm = _stretch_range(data_b_norm, limits_b['low'], limits_b['high'])
+        data_r_norm = _stretch_range(data_r_norm, limits_r["low"], limits_r["high"])
+        data_g_norm = _stretch_range(data_g_norm, limits_g["low"], limits_g["high"])
+        data_b_norm = _stretch_range(data_b_norm, limits_b["low"], limits_b["high"])
 
         R, G, B, RGB = make_cube(data_r_norm, data_g_norm, data_b_norm)
 
-        red_patch = mpatches.Patch(color='red', label=name_r)
-        green_patch = mpatches.Patch(color='green', label=name_g)
-        blue_patch = mpatches.Patch(color='blue', label=name_b)
+        red_patch = mpatches.Patch(color="red", label=name_r)
+        green_patch = mpatches.Patch(color="green", label=name_g)
+        blue_patch = mpatches.Patch(color="blue", label=name_b)
 
-        def format_coord_func(x, y, *, pixel_or_pos, rgb_color_to_keys,
-                              rgb_view_data, pos_limits, colors=None):
+        def format_coord_func(x, y, *, pixel_or_pos, rgb_color_to_keys, rgb_view_data, pos_limits, colors=None):
             x0, y0 = pos_limits["x_low"], pos_limits["y_low"]
             if colors is None:
                 colors = list(rgb_color_to_keys.keys())
 
             s = ""
             for n, color in enumerate(self.rgb_keys):
-                if (color not in colors) or (rgb_color_to_keys[color] is None) \
-                        or (rgb_view_data[color] is None):
+                if (color not in colors) or (rgb_color_to_keys[color] is None) or (rgb_view_data[color] is None):
                     continue
                 map = rgb_view_data[color]
 
@@ -649,11 +668,13 @@ class DrawImageRGB(Atom):
 
             return s_coord + s
 
-        format_coord = partial(format_coord_func,
-                               pixel_or_pos=pixel_or_pos_local,
-                               rgb_color_to_keys=rgb_color_to_keys,
-                               rgb_view_data=rgb_view_data,
-                               pos_limits=pos_limits)
+        format_coord = partial(
+            format_coord_func,
+            pixel_or_pos=pixel_or_pos_local,
+            rgb_color_to_keys=rgb_color_to_keys,
+            rgb_view_data=rgb_view_data,
+            pos_limits=pos_limits,
+        )
 
         def format_cursor_data(data):
             return ""  # Print nothing
@@ -716,8 +737,13 @@ class DrawImageRGB(Atom):
         # ax.text(sb_x + sb_length /2, sb_y - 1*sb_height,  '100 nm', color='w', ha='center',
         #         va='bottom', backgroundcolor='black', fontsize=18)
 
-        self.ax_r.legend(loc="upper left", bbox_to_anchor=(1.1, 0), frameon=False,
-                         handles=[red_patch, green_patch, blue_patch], mode="expand")
+        self.ax_r.legend(
+            loc="upper left",
+            bbox_to_anchor=(1.1, 0),
+            frameon=False,
+            handles=[red_patch, green_patch, blue_patch],
+            mode="expand",
+        )
 
         # self.fig.tight_layout(pad=4.0, w_pad=0.8, h_pad=0.8)
         # self.fig.tight_layout()
@@ -727,8 +753,7 @@ class DrawImageRGB(Atom):
         self.fig.canvas.draw_idle()
 
     def get_selected_items_for_plot(self):
-        """Collect the selected items for plotting.
-        """
+        """Collect the selected items for plotting."""
         # We want the dictionary to be sorted the same way as 'map_keys'
         sdict = self.stat_dict
         selected_keys = [_ for _ in self.map_keys if (_ in sdict) and (sdict[_] is True)]
@@ -737,14 +762,18 @@ class DrawImageRGB(Atom):
     def get_rgb_items_for_plot(self):
         # Verify integrity of the dictionary
         if len(self.rgb_dict) != 3:
-            raise ValueError("DrawImageRGB.get_rgb_items_for_plot: dictionary 'rgb_dict' has "
-                             f"{len(self.rgb_dict)} elements. Expected number of elements: "
-                             f"{len(self.rgb_keys)}.")
+            raise ValueError(
+                "DrawImageRGB.get_rgb_items_for_plot: dictionary 'rgb_dict' has "
+                f"{len(self.rgb_dict)} elements. Expected number of elements: "
+                f"{len(self.rgb_keys)}."
+            )
         for key in self.rgb_keys:
             if key not in self.rgb_dict:
-                raise ValueError("DrawImageRGB.get_rgb_items_for_plot: dictionary 'rgb_dict' is "
-                                 f"incomplete or contains incorrect set of keys: {list(self.rgb_dict.keys())}. "
-                                 f"Expected keys: {self.rgb_keys}: ")
+                raise ValueError(
+                    "DrawImageRGB.get_rgb_items_for_plot: dictionary 'rgb_dict' is "
+                    f"incomplete or contains incorrect set of keys: {list(self.rgb_dict.keys())}. "
+                    f"Expected keys: {self.rgb_keys}: "
+                )
         return self.rgb_dict
 
 
